%define ALD_Ver		1.2

%define OrgName zlib

License:      (C) 1995-2004 Jean-loup Gailly and Mark Adler
Summary:      GNU zlib 1.2.3 is a general purpose data compression library
Group:        System Environment/Libraries
Version:      1.2.3
Release:      2

Source: %{OrgName}-%{version}.tar.xz

%define DestDir		/Embedded/uC-%{uC_Version}

# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%define USE_LOCAL_CROSS 0
%define BUILD_LOCAL_CROSS 0
%define MOVE_TO_ARCH 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _CROSS 1
%define USE_LOCAL_CROSS 1
%define BUILD_LOCAL_CROSS 0
%define MOVE_TO_ARCH 0
%endif

%if %{MOVE_TO_ARCH}
%define TO_ARCH x86_64
%else
%define MOVE_TO_ARCH 0
%endif

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define MOVE_TO_ARCH 1
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mhard-float
%define MOVE_TO_ARCH 1
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1

# -----------------------------------------------------

%if %{BUILD_LOCAL_CROSS}
%if %{MOVE_TO_ARCH}
Name:         uC-%{OrgName}-%{TO_ARCH}
%else
Name:         uC-%{OrgName}-%{_target_cpu}
%endif
%else
Name:         uC-%{OrgName}
%endif

%define uC_Version 0.9.33.2
%define _prefix /usr/uC/%{uC_Version}/static
%define _lib lib

#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
ERROR: target=%{_os}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/usr/uC/%{uC_Version}/static/bin

%if %{BUILD_LOCAL_CROSS}
%define _prefix		%{csysdir}/usr/uC/%{uC_Version}/static
%define CrossDestDir	/Cross
%else
%define CrossDestDir %{nil}
%endif

%if %{USE_LOCAL_CROSS}
%define __os_install_post \
    %{csysbindir}/rpm/brp-strip \
    %{csysbindir}/rpm/brp-strip-static-archive \
    %{csysbindir}/rpm/brp-strip-comment-note \
    %{_rpmconfigdir}/brp-compress \
%{nil}
%endif #USE_LOCAL_CROSS

%define _srcrpmdir %{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysbindir	%{_prefix}/bin
%define CrossDestDir %{nil}
%define _srcrpmdir %{_topdir}/SRPMS/%{ALD_Ver}

%define target %{_arch}-uclibc

%endif # !_CROSS || !TARGETBUILD_CROSS

%define docdir %{_defaultdocdir}/%{OrgName}

# ------------------- description ------------------------------------
%description
This package contains the GNU general purpose data compression library

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{OrgName}-%{version}

# ------------------- Build ------------------------------------------
%Build
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath


%if %{_arch} == "i386"
OPTFLAGS="-Os -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os"
%endif
%if %{_arch} == "arm"
OPTFLAGS="-Os -march=%{ARM_ARCH} %{ARM_FPU}"
%endif

CC="%{target}-gcc"

CFLAGS="$OPTFLAGS -DUNALIGNED_OK -DNDEBUG=1 -ffunction-sections -fdata-sections -fno-tree-loop-optimize -fno-tree-dominator-opts -fno-strength-reduce -fno-stack-protector -std=gnu99"
LDFLAGS="-Wl,--gc-sections"

export CFLAGS LDFLAGS CC

./configure \
	--prefix=%{_prefix} \
	--eprefix=%{_prefix} \
	--libdir=%{_libdir} \
	--includedir=%{_includedir} \
	>FConfigure_log.txt
make >FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

%makeinstall

rm -r $RPM_BUILD_ROOT%{_mandir}/

cp FAQ README $RPM_BUILD_ROOT%{docdir}/

%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean 

%if %{BUILD_LOCAL_CROSS}
  DE=%{version}-%{release}.%{_build_cpu}.rpm
%if %{MOVE_TO_ARCH}
  DD=%{_rpmdir}/%{_build_cpu}/%{ALD_Ver}%{CrossDestDir}/%{TO_ARCH}%{DestDir}
%else
  DD=%{_rpmdir}/%{_build_cpu}/%{ALD_Ver}%{CrossDestDir}/%{_target_cpu}%{DestDir}
%endif

%else  #%{BUILD_LOCAL_CROSS}
%if %{MOVE_TO_ARCH}
  DE=%{version}-%{release}.%{TO_ARCH}.rpm
  DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{CrossDestDir}%{DestDir}
%else
  DE=%{version}-%{release}.%{_target_cpu}.rpm
  DD=%{_rpmdir}/%{_target_cpu}/%{ALD_Ver}%{CrossDestDir}%{DestDir}
%endif
%endif #!%{BUILD_LOCAL_CROSS}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
  TMP_TO=$DD/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}
  mkdir -p $tmp
%if %{BUILD_LOCAL_CROSS}
  cp -r cross $tmp/
%else
  cp -r usr $tmp/
%endif
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
popd
%endif  #BUILD_LOCAL_CROSS

# ------------------- Files ------------------------------------------
%Files
%{docdir}
%{_includedir}
%{_libdir}/*.a

